@@ -675,11 +675,9 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
         if (record.get('houseNumber')) {
             this.houseNumberField.setValue(record.get('houseNumber'))
             this.flatNumberField.setReadOnly(false);
-            this.isSteadSelected = false;
         } else if (record.get('steadNumber')) {
-            this.houseNumberField.setValue(record.get('steadNumber'));
+            this.houseNumberField.setValue('уч. ' + record.get('steadNumber'));
             this.flatNumberField.setReadOnly(true);
-            this.isSteadSelected = true;
         }
         else {
             throw new this.UserException('Ошибка.', 'Не удалось получить номер дома или земельного участка.')
@@ -798,9 +796,9 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
             }
             // значение дома может быть выбрано без указания улицы
             if (this.hasHouseField() && !this.isHouseEmpty()) {
-                if (this.isSteadSelected) {
+                if (this.houseNumberField.getValue().indexOf('уч.') > -1) {
                     addressParts.push(
-                    'земельный участок ' + this.houseNumberField.getValue()
+                     'земельный участок ' + this.houseNumberField.getValue().substring(4)
                     );
                 }
                 else {
